Test selectWindow
open | ../tests/html/test_select_window.html |
click | popupPage |
waitForPopUp | myPopupWindow | 5000
selectWindow | myPopupWindow |
verifyLocation | */tests/html/test_select_window_popup.html |
close |  |
assertErrorOnNext | Current window or frame is closed! |
verifyLocation | */tests/html/test_select_window_popup.html |

Leave the test in a selected window - the next test should begin in the main window